==> jboss-4.0.2.zip: jaxrpc/src/main/org/jboss/axis/message/DetailImpl.java <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2002-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.jboss.axis.message;

import org.jboss.axis.AxisFault;
import org.jboss.axis.encoding.DeserializationContext;
import org.xml.sax.Attributes;

import javax.xml.soap.Detail;
import javax.xml.soap.DetailEntry;
import javax.xml.soap.Name;
import javax.xml.soap.SOAPException;
import java.util.Iterator;

/**
 * Detail Container implementation
 *
 * @author Davanum Srinivas (dims@yahoo.com)
 */
public class DetailImpl extends SOAPFaultImpl implements Detail
{

   public DetailImpl(String namespace, String localName, String prefix,
                     Attributes attrs, DeserializationContext context)
           throws AxisFault
   {
      super(namespace, localName, prefix, attrs, context);
   }

   public DetailImpl()
   {
      super(new AxisFault());
   }

   public DetailImpl(AxisFault fault)
   {
      super(fault);
   }

   /**
    * Creates a new <code>DetailEntry</code> object with the given
    * name and adds it to this <code>Detail</code> object.
    *
    * @param name a <code>Name</code> object identifying the new <code>DetailEntry</code> object
    * @return DetailEntry.
    * @throws SOAPException thrown when there is a problem in adding a DetailEntry object to this Detail object.
    */
   public DetailEntry addDetailEntry(Name name) throws SOAPException
   {
      org.jboss.axis.message.DetailEntryImpl entry = new org.jboss.axis.message.DetailEntryImpl(name);
      addChildElement(entry);
      if (fault != null)
      {
         try
         {
            fault.addFaultDetail(entry.getAsDOM());
         }
         catch (Exception e)
         {
            throw new SOAPException(e);
         }
      }
      return entry;
   }

   /**
    * Gets a list of the detail entries in this <code>Detail</code> object.
    *
    * @return an <code>Iterator</code> object over the <code>DetailEntry</code>
    *         objects in this <code>Detail</code> object
    */
   public Iterator getDetailEntries()
   {
      return this.getChildElements();
   }
}

==> jboss-4.0.4.zip: jaxrpc/src/main/org/jboss/axis/message/DetailImpl.java <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2002-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Axis" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.jboss.axis.message;

import org.jboss.axis.AxisFault;
import org.jboss.axis.encoding.DeserializationContext;
import org.jboss.axis.utils.DOM2Utils;
import org.w3c.dom.Element;
import org.xml.sax.Attributes;

import javax.xml.soap.Detail;
import javax.xml.soap.DetailEntry;
import javax.xml.soap.Name;
import javax.xml.soap.SOAPException;
import java.util.Iterator;

/**
 * Detail Container implementation
 *
 * @author Davanum Srinivas (dims@yahoo.com)
 */
public class DetailImpl extends SOAPFaultImpl implements Detail
{

   public DetailImpl(String namespace, String localName, String prefix,
                     Attributes attrs, DeserializationContext context)
           throws AxisFault
   {
      super(namespace, localName, prefix, attrs, context);
   }

   public DetailImpl()
   {
      super(DOM2Utils.createElement(null, "detail"));
      this.fault = new AxisFault(); 
   }

   public DetailImpl(AxisFault fault) 
   {
      super(DOM2Utils.createElement(null, "detail"));
      this.fault = fault; 
   }

   public DetailImpl(Element elem)
   {
      super(elem);
   }

   /**
    * Creates a new <code>DetailEntry</code> object with the given
    * name and adds it to this <code>Detail</code> object.
    *
    * @param name a <code>Name</code> object identifying the new <code>DetailEntry</code> object
    * @return DetailEntry.
    * @throws SOAPException thrown when there is a problem in adding a DetailEntry object to this Detail object.
    */
   public DetailEntry addDetailEntry(Name name) throws SOAPException
   {
      org.jboss.axis.message.DetailEntryImpl entry = new org.jboss.axis.message.DetailEntryImpl(name);
      addChildElement(entry);
      if (fault != null)
      {
         try
         {
            fault.addFaultDetail(entry.getAsDOM());
         }
         catch (Exception e)
         {
            throw new SOAPException(e);
         }
      }
      return entry;
   }

   /**
    * Gets a list of the detail entries in this <code>Detail</code> object.
    *
    * @return an <code>Iterator</code> object over the <code>DetailEntry</code>
    *         objects in this <code>Detail</code> object
    */
   public Iterator getDetailEntries()
   {
      return this.getChildElements();
   }
}
